# import pathlib
# import configparser
# import hashlib
# import requests
# import json
#
# def _credentials():
#     try:
#         config_dir = pathlib.Path.home() / '.devnull'
#         pathlib.Path(config_dir).mkdir(parents=True, exist_ok=True)
#         _c = config_dir / 'credentials'
#         with _c.open('r') as f:
#             config = configparser.ConfigParser()
#             config.read_file(f)
#             accesskey = config['default']['accesskey']
#             secretkey = config['default']['secretkey']
#             email = config['default']['email']
#     except:
#         accesskey = 'Eo3YeVIcJzUCUgs2so8qb7pt'
#         secretkey = '8LmdaD0MPen7mPkrDa4F97oW'
#         email = 'ddns-free@thedns.cn'
#     return accesskey, secretkey, email
#
#
# def _token(email, access_key, secret_key):
#     hashed_access_key = hashlib.sha256(access_key.encode()).hexdigest()
#     hashed_secret_key = hashlib.sha256(secret_key.encode()).hexdigest()
#     hashed_email = hashlib.md5(email.encode()).hexdigest()
#     _plain = hashed_access_key + hashed_secret_key
#     _password = hashlib.sha256(_plain.encode()).hexdigest()
#     # print(_password)
#     data = json.dumps({
#         'email': email,
#         'checksum': hashed_email,
#         'accesskey': access_key,
#         'password': _password,
#         'resource_type': 'token'
#     })
#     headers = {'Content-Type': 'application/json'}
#     _= requests.post('https://devnull.cn/identity', data=data, headers=headers).json()
#     token_string = 'Bearer ' + _['token']
#     return token_string
#
# def _request_headers(token=None):
#     return {
#         'Authorization': token,
#         'Content-Type': 'application/json'
#     }


# import socket
# import hashlib
#
# def _get_private_ip():
#     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
#     s.connect(('8.8.8.8', 80))
#     private_ip_string = s.getsockname()[0]
#     s.close()
#     return private_ip_string
#
# def _get_rr_string():
#     try:
#         with open('/etc/machine-id', 'r') as f:
#             rr_string = hashlib.md5(f.read().encode()).hexdigest()
#     except:
#         rr_string = hashlib.md5(socket.gethostname().encode()).hexdigest()
#     return rr_string



import json
import requests

def _list_rrs(url=None, request_headers=None):
    _payload = json.dumps({
        "action_type": 'list_rrs_free',
    })
    _response_list_rrs = requests.post(url, headers=request_headers, data=_payload).json()
    return _response_list_rrs


def _update_rr(request_headers=None, rr_record=None, rr_value=None):
        ddns_request_type = 'create_rr_free'
        payload_rr_id = None
        rrs = _list_rrs(url='https://devnull.cn/dns', request_headers=request_headers)
        rrs_reformed = dict()
        for _id in rrs:
            _record = rrs[_id]['rr_record']
            _value = rrs[_id]['rr_value']
            rrs_reformed[_record] = {
                '_id': _id,
                '_value': _value
            }
        for _rr in rrs_reformed:
            _value = rrs_reformed[_rr]['_value']
            _id = rrs_reformed[_rr]['_id']
            if _rr == rr_record:
                if _value != rr_value:
                    ddns_request_type = 'update_rr_free'
                    payload_rr_id = rrs_reformed[_rr]['_id']
                else:
                    ddns_request_type = 'take_no_action'
                break
        final_payload = _build_payload(ddns_request_type=ddns_request_type, rr_record=rr_record, rr_value=rr_value)
        final_payload['rr_id'] = payload_rr_id
        # print(f"Updating RR: {rr_record}.thedns.cn || {rr_value}")
        _request = requests.post('https://devnull.cn/dns',
                                 headers=request_headers,
                                 data=json.dumps(final_payload)).json()

def _build_payload(ddns_request_type=None, rr_record=None, rr_value=None):
        return {
            "action_type": ddns_request_type,
            "rr_type": 'A',
            "rr_record": rr_record,
            "rr_value": rr_value,
        }


import pathlib
from theid import authorization_headers, system_id, email, private_ip, public_ip, hostname

from ._wanwang import _list_rrs
from ._wanwang import _build_payload
from ._wanwang import _update_rr

_owner = email()
_hostname = hostname()
_system_id = system_id()
_private_ip = private_ip()
_public_ip = public_ip()
_rr_string_private = _system_id + '.private'
_rr_string_public = _system_id + '.public'

def update():
    _update_rr(request_headers=authorization_headers(), rr_record=_rr_string_private,rr_value=_private_ip)
    _update_rr(request_headers=authorization_headers(), rr_record=_rr_string_public,rr_value=_public_ip)
    config_dir = pathlib.Path.home() / '.devnull'
    pathlib.Path(config_dir).mkdir(parents=True, exist_ok=True)
    fqdn_file = config_dir / 'fqdn'
    with fqdn_file.open('wt') as f:
        f.write('\n'.join([_system_id,
                           _hostname,
                           _private_ip,
                           _public_ip,
                           _rr_string_public + '.thedns.cn',
                           _rr_string_private + '.thedns.cn',
                           '']))
    return {
        _rr_string_public + '.thedns.cn': _public_ip,
        _rr_string_private + '.thedns.cn': _private_ip,
        'fqdn': fqdn_file.as_posix(),
        'owner': _owner
    }

# class DDNS(object):
#     access_key = None
#     secret_key = None
#     email = None
#     public_ip = None
#     private_ip = None
#     token = None
#     request_headers = None
#     def __init__(self):
#         self.access_key, self.secret_key, self.email = _credentials()
#         self.public_ip = requests.get('https://devnull.cn/ip').json()['origin']
#         self.private_ip = _get_private_ip()
#         self.token = _token(self.email, self.access_key, self.secret_key)
#         self.request_headers = _request_headers(token=self.token)
#         self.system_uuid = _get_rr_string()
#         self.rr_string_public = self.system_uuid + '.public'
#         self.rr_string_private = self.system_uuid + '.private'
#     def update(self):
#         _update_rr(request_headers=self.request_headers, rr_record=self.rr_string_private,rr_value=self.private_ip)
#         _update_rr(request_headers=self.request_headers, rr_record=self.rr_string_public,rr_value=self.public_ip)
#         config_dir = pathlib.Path.home() / '.devnull'
#         pathlib.Path(config_dir).mkdir(parents=True, exist_ok=True)
#         fqdn_file = config_dir / 'fqdn'
#         with fqdn_file.open('wt') as f:
#             f.write('\n'.join([self.system_uuid,
#                                socket.gethostname(),
#                                self.private_ip,
#                                self.public_ip,
#                                self.rr_string_public + '.thedns.cn',
#                                self.rr_string_private + '.thedns.cn',
#                                '']))
#         return {
#             self.rr_string_public + '.thedns.cn': self.public_ip,
#             self.rr_string_private + '.thedns.cn': self.private_ip,
#             'fqdn': fqdn_file.as_posix(),
#         }



from setuptools import setup

setup(
    name='thedns',
    version='2.0.1',
    author='Xizhen Du',
    author_email='xizhendu@gmail.com',
    url='https://github.com/xizhendu/thedns-sdk-python',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    description='Simple Python client library for TheDNS.cn',
    # packages=['thedns'],
    install_requires=[
        "requests",
        "theid"
    ]
)
